@@ -237,10 +237,6 @@ class Synth(Inferences, Plot, DataProcessor):
                     self.original_data.control_outcome, self.original_data.control_covariates, 
                     self.original_data, False, n_optim)
         
-        #Visualize synthetic control
-        self.plot(["original", "pointwise", "cumulative"],
-                    (15, 12),
-                    self.original_data.treated_unit)
 
 class DiffSynth(Inferences, Plot, DataProcessor):
 
@@ -267,12 +263,6 @@ class DiffSynth(Inferences, Plot, DataProcessor):
         self.optimize(self.modified_data.treated_outcome, self.modified_data.treated_covariates,
                     self.modified_data.control_outcome, self.modified_data.control_covariates, 
                     self.modified_data, False, n_optim)
-        '''
-        #Visualize synthetic control
-        self.plot(["original", "pointwise", "cumulative"],
-                    (15, 12),
-                    self.original_data.treated_unit)
-        '''
 
     def difference_data(self, dataset, not_diff_cols):
         '''
